@@ -92,448 +92,448 @@ class FuncMusic(object):
 
 
 # WIP Class for parsing json revenue builds in graph structure (as opposed to tree)
-class FormulaGraph:
-    def __init__(
-        self,
-        file_name=None,
-        ticker=None,
-        auto_parse=True,
-        force=False,  # determines if the file json file will be force pulled from s3
-    ):
+# class FormulaGraph:
+# def __init__(
+#     self,
+#     file_name=None,
+#     ticker=None,
+#     auto_parse=True,
+#     force=False,  # determines if the file json file will be force pulled from s3
+# ):
 
-        # Raise an error if a ticker or file name is not entered
-        if not ticker and not file_name:
-            raise ValueError(
-                "You must pass in a value for either the ticker "
-                "argument or file_name argument"
-            )
-        elif ticker and file_name:
-            raise ValueError(
-                "Only pass in a value for ticker OR file_name, not both. "
-                "If you pass a ticker, the data will be pulled from s3. "
-                "If you pass a file_name, the data will be pulled from that json file."
-            )
+#     # Raise an error if a ticker or file name is not entered
+#     if not ticker and not file_name:
+#         raise ValueError(
+#             "You must pass in a value for either the ticker "
+#             "argument or file_name argument"
+#         )
+#     elif ticker and file_name:
+#         raise ValueError(
+#             "Only pass in a value for ticker OR file_name, not both. "
+#             "If you pass a ticker, the data will be pulled from s3. "
+#             "If you pass a file_name, the data will be pulled from that json file."
+#         )
 
-        # Set json_file instance var if a valid file was passed
-        self.json_file = ""
-        if os.path.isfile(file_name):
-            self.json_file = file_name
-        else:
-            raise ValueError(
-                f"The value you passed for file_name, {file_name}, is not a valid"
-                "JSON file"
-            )
+#     # Set json_file instance var if a valid file was passed
+#     self.json_file = ""
+#     if os.path.isfile(file_name):
+#         self.json_file = file_name
+#     else:
+#         raise ValueError(
+#             f"The value you passed for file_name, {file_name}, is not a valid"
+#             "JSON file"
+#         )
 
-        # set instance variables
-        self.ticker = ticker
-        self.auto = auto_parse
-        self.force = force
-        self.node_dict = self.read_json()  # dictionary of all nodes in the tree
+#     # set instance variables
+#     self.ticker = ticker
+#     self.auto = auto_parse
+#     self.force = force
+#     self.node_dict = self.read_json()  # dictionary of all nodes in the tree
 
-        # instance variables to be set in parse_formula_graph()
-        self.formula_strings = (
-            {}
-        )  # use dynamic programming/memoization to store the formula strings of each node in the tree
-        self.drivers = {}  # drivers and their values
-        self.labels = {}  # node: time_series_description
+#     # instance variables to be set in parse_formula_graph()
+#     self.formula_strings = (
+#         {}
+#     )  # use dynamic programming/memoization to store the formula strings of each node in the tree
+#     self.drivers = {}  # drivers and their values
+#     self.labels = {}  # node: time_series_description
 
-        # automatically create string representation and code expression (without custom drivers)
-        if auto_parse:
-            # create a string representation of the precedent formula and dictionary of drivers, and compile into code expression
-            self.parse_formula_graph()
+#     # automatically create string representation and code expression (without custom drivers)
+#     if auto_parse:
+#         # create a string representation of the precedent formula and dictionary of drivers, and compile into code expression
+#         self.parse_formula_graph()
 
-    # return the node dictionary from the json file
-    def read_json(self):
-        with open(self.json_file) as f:
-            return json.load(f)["NodeDict"]
+# # return the node dictionary from the json file
+# def read_json(self):
+#     with open(self.json_file) as f:
+#         return json.load(f)["NodeDict"]
 
-    def parse_formula_graph(self):
-        # by default we will parse the first cell in the json
-        cell = list(self.node_dict.values())[0]
+# def parse_formula_graph(self):
+#     # by default we will parse the first cell in the json
+#     cell = list(self.node_dict.values())[0]
 
-        self.string_representation = self.calculate_formula_string(cell)
+#     self.string_representation = self.calculate_formula_string(cell)
 
-    # recursive method which calculates the formula string of the given cell/node
-    def calculate_formula_string(
-        self, cell: dict  # dictionary with info for the given cell
-    ):
+# # recursive method which calculates the formula string of the given cell/node
+# def calculate_formula_string(
+#     self, cell: dict  # dictionary with info for the given cell
+# ):
 
-        # cells id's are in the formula mo_name|period, so replace the vertical line with an underscore
-        # and the "-" in the period
-        cell_id = cell["Id"].replace("|", "_").replace("-", "_")
+#     # cells id's are in the formula mo_name|period, so replace the vertical line with an underscore
+#     # and the "-" in the period
+#     cell_id = cell["Id"].replace("|", "_").replace("-", "_")
 
-        # base case: if the cell is a driver or has no precedents (bottom of tree)
-        if cell["PrecedentIds"] == []:
-            # add drivers to the dictionary of drivers, replace the value of non drivers with their values
-            if cell["IsDriver"]:
-                self.drivers[cell_id] = float(cell["Value"])
-                self.labels[cell_id] = cell["TimeSeriesDescription"]
+#     # base case: if the cell is a driver or has no precedents (bottom of tree)
+#     if cell["PrecedentIds"] == []:
+#         # add drivers to the dictionary of drivers, replace the value of non drivers with their values
+#         if cell["IsDriver"]:
+#             self.drivers[cell_id] = float(cell["Value"])
+#             self.labels[cell_id] = cell["TimeSeriesDescription"]
 
-                to_return = cell_id
-            else:
-                v = cell["Value"]
-                if v is None:
-                    v = "0.0"
-                to_return = v
+#             to_return = cell_id
+#         else:
+#             v = cell["Value"]
+#             if v is None:
+#                 v = "0.0"
+#             to_return = v
 
-            return f"({to_return})"
+#         return f"({to_return})"
 
-        # get formula of this cell
-        if cell["Formula"]:
-            formula = cell["Formula"].replace("=", "")
-            formula = formula[0].replace("+", "") + formula[1:]
+#     # get formula of this cell
+#     if cell["Formula"]:
+#         formula = cell["Formula"].replace("=", "")
+#         formula = formula[0].replace("+", "") + formula[1:]
 
-        # change ^ (exp in excel) to ** (exp in python)
-        formula = formula.replace("^", "**")
+#     # change ^ (exp in excel) to ** (exp in python)
+#     formula = formula.replace("^", "**")
 
-        if len(cell["PrecedentIds"]) > 2:
-            print("test")
+#     if len(cell["PrecedentIds"]) > 2:
+#         print("test")
 
-        # recursive case: replace each cell in this cells formula with that cells formula
-        for prec_cell_id in cell["PrecedentIds"]:
+#     # recursive case: replace each cell in this cells formula with that cells formula
+#     for prec_cell_id in cell["PrecedentIds"]:
 
-            prec_cell = self.node_dict[prec_cell_id]
-            val_to_replace = prec_cell["SimpleAddress"]
+#         prec_cell = self.node_dict[prec_cell_id]
+#         val_to_replace = prec_cell["SimpleAddress"]
 
-            # if formula has not been memoized, calculate it
-            if prec_cell_id not in self.formula_strings:
-                self.formula_strings[prec_cell_id] = self.calculate_formula_string(
-                    prec_cell
-                )
+#         # if formula has not been memoized, calculate it
+#         if prec_cell_id not in self.formula_strings:
+#             self.formula_strings[prec_cell_id] = self.calculate_formula_string(
+#                 prec_cell
+#             )
 
-            # Currently, each cell does not reference each of it's precedent cells, so:
-            # In order to solve this I would have to loop through each cell id in formula_strings and
-            # replace its simple address with its formula string, which would mean slower runtime here
-            val_to_insert = self.formula_strings[prec_cell_id]
+#         # Currently, each cell does not reference each of it's precedent cells, so:
+#         # In order to solve this I would have to loop through each cell id in formula_strings and
+#         # replace its simple address with its formula string, which would mean slower runtime here
+#         val_to_insert = self.formula_strings[prec_cell_id]
 
-            # replace the cell address with its formula
-            if val_to_replace in formula:
-                # use re.sub with \bstr\b to only replace exactly that formula
-                formula = re.sub(
-                    r"\b" + val_to_replace + r"\b", f"({val_to_insert})", formula
-                )
+#         # replace the cell address with its formula
+#         if val_to_replace in formula:
+#             # use re.sub with \bstr\b to only replace exactly that formula
+#             formula = re.sub(
+#                 r"\b" + val_to_replace + r"\b", f"({val_to_insert})", formula
+#             )
 
-        return formula
+#     return formula
 
-    # evaluate the code derived from the string using the drivers default passed in values
-    def evaluate_node(self, node_id=None, drivers=None):
-        # default to using the normal drivers
-        if type(drivers) != dict:
-            drivers = self.drivers
-        else:
-            drivers = {
-                **self.drivers,
-                **drivers,
-            }  # replace drivers with passed in values
+# # evaluate the code derived from the string using the drivers default passed in values
+# def evaluate_node(self, node_id=None, drivers=None):
+#     # default to using the normal drivers
+#     if type(drivers) != dict:
+#         drivers = self.drivers
+#     else:
+#         drivers = {
+#             **self.drivers,
+#             **drivers,
+#         }  # replace drivers with passed in values
 
-        functions = {
-            "SUM": lambda *nums: sum(nums),
-            "AVERAGE": lambda *nums: sum(nums) / len(nums),
-            "ROUND": lambda num, decimal_pts: round(num, decimal_pts),
-            "EOMONTH": self.eomonth,
-        }
+#     functions = {
+#         "SUM": lambda *nums: sum(nums),
+#         "AVERAGE": lambda *nums: sum(nums) / len(nums),
+#         "ROUND": lambda num, decimal_pts: round(num, decimal_pts),
+#         "EOMONTH": self.eomonth,
+#     }
 
-        if node_id is None:
-            return eval(self.string_representation, {}, {**drivers, **functions})
-        else:
-            return eval(self.formula_strings[node_id], {}, {**drivers, **functions})
+#     if node_id is None:
+#         return eval(self.string_representation, {}, {**drivers, **functions})
+#     else:
+#         return eval(self.formula_strings[node_id], {}, {**drivers, **functions})
 
-    # mimics excel function needed for evaluating some formula strings
-    def eomonth(self, date, num_months):
+# # mimics excel function needed for evaluating some formula strings
+# def eomonth(self, date, num_months):
 
-        # parsing the date string, only take the first part since all the dates seem to be 12:00:00 AM
-        split_date = date.split()
-        date = split_date[0]
+#     # parsing the date string, only take the first part since all the dates seem to be 12:00:00 AM
+#     split_date = date.split()
+#     date = split_date[0]
 
-        # print a message just incase there's a date that's not 12:00:00 AM
-        if " ".join(split_date[1:]) != "12:00:00 AM":
-            print(
-                "time is not 12 am. this might cause an issue"
-                " in the eomonth function in the FormulaTree class"
-            )
+#     # print a message just incase there's a date that's not 12:00:00 AM
+#     if " ".join(split_date[1:]) != "12:00:00 AM":
+#         print(
+#             "time is not 12 am. this might cause an issue"
+#             " in the eomonth function in the FormulaTree class"
+#         )
 
-        import calendar
+#     import calendar
 
-        def add_months(sourcedate, months):
-            month = sourcedate.month - 1 + months
-            year = sourcedate.year + month // 12
-            month = month % 12 + 1
-            day = min(sourcedate.day, calendar.monthrange(year, month)[1])
-            return datetime.datetime(year, month, day)
+#     def add_months(sourcedate, months):
+#         month = sourcedate.month - 1 + months
+#         year = sourcedate.year + month // 12
+#         month = month % 12 + 1
+#         day = min(sourcedate.day, calendar.monthrange(year, month)[1])
+#         return datetime.datetime(year, month, day)
 
-        # create a datetime object out of the date parameter
-        SECONDS_IN_A_DAY = 86400
-        date = datetime.datetime.fromisoformat(date)
+#     # create a datetime object out of the date parameter
+#     SECONDS_IN_A_DAY = 86400
+#     date = datetime.datetime.fromisoformat(date)
 
-        # add months to the date and get the last date of the month the date is in
-        date = add_months(date, num_months)
-        date = datetime.datetime(
-            (date.year + (date.month // 12)), (date.month + 1) % 12, 1
-        ) - datetime.timedelta(days=1)
+#     # add months to the date and get the last date of the month the date is in
+#     date = add_months(date, num_months)
+#     date = datetime.datetime(
+#         (date.year + (date.month // 12)), (date.month + 1) % 12, 1
+#     ) - datetime.timedelta(days=1)
 
-        # return the timestamp as a number of days as opposed to seconds
-        date = datetime.datetime.timestamp(date) / SECONDS_IN_A_DAY
-        return date
+#     # return the timestamp as a number of days as opposed to seconds
+#     date = datetime.datetime.timestamp(date) / SECONDS_IN_A_DAY
+#     return date
 
 
 # helper class to read a formula json
-class FormulaTree:
+# class FormulaTree:
 
-    # author Sebastian Fisher 6-30-2021
-    # json created by Ian Paul 2021
-    def __init__(
-        self,
-        config: Config = None,
-        file_name=None,
-        ticker=None,
-        auto_parse=True,
-        force=False,
-    ):
-        self.config = config or CONFIG
-        self.s3_client = Getter(self.config)
-        if not ticker and not file_name:
-            raise ValueError(
-                "You must pass in a value for either the ticker argument or file_name argument"
-            )
-        elif ticker and file_name:
-            raise ValueError(
-                "Only pass in a value for ticker OR file_name, not both. If you pass a ticker, the data will be pulled from s3. If you pass a file_name, the data will be pulled from that json file."
-            )
+# author Sebastian Fisher 6-30-2021
+# json created by Ian Paul 2021
+# def __init__(
+#     self,
+#     config: Config = None,
+#     file_name=None,
+#     ticker=None,
+#     auto_parse=True,
+#     force=False,
+# ):
+#     self.config = config or CONFIG
+#     self.s3_client = Getter(self.config)
+#     if not ticker and not file_name:
+#         raise ValueError(
+#             "You must pass in a value for either the ticker argument or file_name argument"
+#         )
+#     elif ticker and file_name:
+#         raise ValueError(
+#             "Only pass in a value for ticker OR file_name, not both. If you pass a ticker, the data will be pulled from s3. If you pass a file_name, the data will be pulled from that json file."
+#         )
 
-        self.json_file = ""
-        self.ticker = ticker
-        if ticker:
-            # get rid of country symbol from ticker
-            ticker = ticker.split()[0]
-            # file on s3
-            from_filename = f"DATA/{ticker}/{ticker}_revenue.json"
-            # location to download
-            to_dir = os.path.join(self.config.default_dir, f"DATA/{ticker}")
-            to_filename = os.path.join(to_dir, f"{ticker}_revenue.json")
+#     self.json_file = ""
+#     self.ticker = ticker
+#     if ticker:
+#         # get rid of country symbol from ticker
+#         ticker = ticker.split()[0]
+#         # file on s3
+#         from_filename = f"DATA/{ticker}/{ticker}_revenue.json"
+#         # location to download
+#         to_dir = os.path.join(self.config.default_dir, f"DATA/{ticker}")
+#         to_filename = os.path.join(to_dir, f"{ticker}_revenue.json")
 
-            self.json_file = to_filename
+#         self.json_file = to_filename
 
-            # if the file doesn't exist, attempt to pull from s3
-            if not os.path.isfile(to_filename) or force:
-                # Make directories to file if they don't exist
-                os.makedirs(to_dir, exist_ok=True)
-                self.s3_client.get_s3_file(to_filename, from_filename)
+#         # if the file doesn't exist, attempt to pull from s3
+#         if not os.path.isfile(to_filename) or force:
+#             # Make directories to file if they don't exist
+#             os.makedirs(to_dir, exist_ok=True)
+#             self.s3_client.get_s3_file(to_filename, from_filename)
 
-        else:
-            if os.path.isfile(file_name):
-                self.json_file = file_name
-            else:
-                raise ValueError(
-                    "The value you passed for file_name,"
-                    f" {file_name}, is not a valid JSON file."
-                )
+#     else:
+#         if os.path.isfile(file_name):
+#             self.json_file = file_name
+#         else:
+#             raise ValueError(
+#                 "The value you passed for file_name,"
+#                 f" {file_name}, is not a valid JSON file."
+#             )
 
-        self.auto = auto_parse
+#     self.auto = auto_parse
 
-        # These will be set later on in parse_formula_tree
-        self.string_representation = None
-        self.drivers = None
-        self.custom_drivers = None
-        self.driver_labels = None
-        self.formula_code = None
-        self.betas = {}
-        self.cell_formulas = {}
+#     # These will be set later on in parse_formula_tree
+#     self.string_representation = None
+#     self.drivers = None
+#     self.custom_drivers = None
+#     self.driver_labels = None
+#     self.formula_code = None
+#     self.betas = {}
+#     self.cell_formulas = {}
 
-        # automatically create string representation and code expression (without custom drivers)
-        if auto_parse:
-            # create a string representation of the precedent formula and dictionary of drivers, and compile into code expression
-            self.parse_formula_tree()
+#     # automatically create string representation and code expression (without custom drivers)
+#     if auto_parse:
+#         # create a string representation of the precedent formula and dictionary of drivers, and compile into code expression
+#         self.parse_formula_tree()
 
-    # Find "beta" value for each driver and custom driver
-    def find_betas(self):
-        curr_rev = self.evaluate_node()
-        self.betas = self.find_betas_helper(self.drivers, curr_rev)
-        self.betas.update(self.find_betas_helper(self.custom_drivers, curr_rev))
+# # Find "beta" value for each driver and custom driver
+# def find_betas(self):
+#     curr_rev = self.evaluate_node()
+#     self.betas = self.find_betas_helper(self.drivers, curr_rev)
+#     self.betas.update(self.find_betas_helper(self.custom_drivers, curr_rev))
 
-    def find_betas_helper(self, drivers_dict, curr_rev):
-        betas = {}
-        for driver in drivers_dict:
-            curr_val = drivers_dict[driver]
-            new_rev = self.evaluate_node(drivers={driver: curr_val * 1.01})
-            beta = (new_rev - curr_rev) / curr_rev
-            betas[driver] = beta
-        return betas
+# def find_betas_helper(self, drivers_dict, curr_rev):
+#     betas = {}
+#     for driver in drivers_dict:
+#         curr_val = drivers_dict[driver]
+#         new_rev = self.evaluate_node(drivers={driver: curr_val * 1.01})
+#         beta = (new_rev - curr_rev) / curr_rev
+#         betas[driver] = beta
+#     return betas
 
-    # evaluate the code derived from the string using the drivers default passed in values
-    def evaluate_node(self, time_series="MO_RIS_REV", drivers=None):
-        # default to using the normal drivers
-        if type(drivers) != dict:
-            drivers = {**self.drivers, **self.custom_drivers}
-        else:
-            drivers = {
-                **self.drivers,
-                **self.custom_drivers,
-                **drivers,
-            }  # replace drivers with passed in values
+# # evaluate the code derived from the string using the drivers default passed in values
+# def evaluate_node(self, time_series="MO_RIS_REV", drivers=None):
+#     # default to using the normal drivers
+#     if type(drivers) != dict:
+#         drivers = {**self.drivers, **self.custom_drivers}
+#     else:
+#         drivers = {
+#             **self.drivers,
+#             **self.custom_drivers,
+#             **drivers,
+#         }  # replace drivers with passed in values
 
-        functions = {
-            "SUM": lambda *nums: sum(nums),
-            "AVERAGE": lambda *nums: sum(nums) / len(nums),
-            "ROUND": lambda num, decimal_pts: round(num, decimal_pts),
-            "EOMONTH": self.eomonth,
-        }
+#     functions = {
+#         "SUM": lambda *nums: sum(nums),
+#         "AVERAGE": lambda *nums: sum(nums) / len(nums),
+#         "ROUND": lambda num, decimal_pts: round(num, decimal_pts),
+#         "EOMONTH": self.eomonth,
+#     }
 
-        if time_series == "MO_RIS_REV":
-            return eval(self.formula_code, {}, {**drivers, **functions})
-        else:
-            return eval(self.cell_formulas[time_series], {}, {**drivers, **functions})
+#     if time_series == "MO_RIS_REV":
+#         return eval(self.formula_code, {}, {**drivers, **functions})
+#     else:
+#         return eval(self.cell_formulas[time_series], {}, {**drivers, **functions})
 
-    # defining needed excel function
-    def eomonth(date, num_months):
+# # defining needed excel function
+# def eomonth(date, num_months):
 
-        # parsing the date string, only take the first part since all the dates seem to be 12:00:00 AM
-        split_date = date.split()
-        date = split_date[0]
+#     # parsing the date string, only take the first part since all the dates seem to be 12:00:00 AM
+#     split_date = date.split()
+#     date = split_date[0]
 
-        # print a message just incase there's a date that's not 12:00:00 AM
-        if " ".join(split_date[1:]) != "12:00:00 AM":
-            print(
-                "time is not 12 am. this might cause an issue"
-                " in the eomonth function in the FormulaTree class"
-            )
+#     # print a message just incase there's a date that's not 12:00:00 AM
+#     if " ".join(split_date[1:]) != "12:00:00 AM":
+#         print(
+#             "time is not 12 am. this might cause an issue"
+#             " in the eomonth function in the FormulaTree class"
+#         )
 
-        import calendar
+#     import calendar
 
-        def add_months(sourcedate, months):
-            month = sourcedate.month - 1 + months
-            year = sourcedate.year + month // 12
-            month = month % 12 + 1
-            day = min(sourcedate.day, calendar.monthrange(year, month)[1])
-            return datetime.datetime(year, month, day)
+#     def add_months(sourcedate, months):
+#         month = sourcedate.month - 1 + months
+#         year = sourcedate.year + month // 12
+#         month = month % 12 + 1
+#         day = min(sourcedate.day, calendar.monthrange(year, month)[1])
+#         return datetime.datetime(year, month, day)
 
-        # create a datetime object out of the date parameter
-        SECONDS_IN_A_DAY = 86400
-        date = datetime.datetime.fromisoformat(date)
+#     # create a datetime object out of the date parameter
+#     SECONDS_IN_A_DAY = 86400
+#     date = datetime.datetime.fromisoformat(date)
 
-        # add months to the date and get the last date of the month the date is in
-        date = add_months(date, num_months)
-        date = datetime.datetime(
-            (date.year + (date.month // 12)), (date.month + 1) % 12, 1
-        ) - datetime.timedelta(days=1)
+#     # add months to the date and get the last date of the month the date is in
+#     date = add_months(date, num_months)
+#     date = datetime.datetime(
+#         (date.year + (date.month // 12)), (date.month + 1) % 12, 1
+#     ) - datetime.timedelta(days=1)
 
-        # return the timestamp as a number of days as opposed to seconds
-        date = datetime.datetime.timestamp(date) / SECONDS_IN_A_DAY
-        return date
+#     # return the timestamp as a number of days as opposed to seconds
+#     date = datetime.datetime.timestamp(date) / SECONDS_IN_A_DAY
+#     return date
 
-    # Creates a string representation of the formula tree
-    def parse_formula_tree(self, custom_drivers_list=[]):
+# # Creates a string representation of the formula tree
+# def parse_formula_tree(self, custom_drivers_list=[]):
 
-        # load the file from json
-        with open(self.json_file) as f:
-            cell_data = json.load(f)
+#     # load the file from json
+#     with open(self.json_file) as f:
+#         cell_data = json.load(f)
 
-        # Set up a dictionary for the values and labels of each driver variable
-        drivers = {}
-        labels = {}
+#     # Set up a dictionary for the values and labels of each driver variable
+#     drivers = {}
+#     labels = {}
 
-        # Set up a dictionary for formula for each node in the tree
-        self.cell_formulas = {}
+#     # Set up a dictionary for formula for each node in the tree
+#     self.cell_formulas = {}
 
-        # start out with each custom driver as None value
-        custom_drivers_list = list(custom_drivers_list)
-        custom_drivers = dict((driver, None) for driver in custom_drivers_list)
+#     # start out with each custom driver as None value
+#     custom_drivers_list = list(custom_drivers_list)
+#     custom_drivers = dict((driver, None) for driver in custom_drivers_list)
 
-        # call function to recur to precedent cells
-        formula = self.create_cell_string_representation(
-            cell_data, drivers, labels, custom_drivers
-        )
+#     # call function to recur to precedent cells
+#     formula = self.create_cell_string_representation(
+#         cell_data, drivers, labels, custom_drivers
+#     )
 
-        # set values of instance variables
-        self.string_representation = formula
-        self.drivers = drivers
-        self.custom_drivers = custom_drivers
-        self.driver_labels = labels
+#     # set values of instance variables
+#     self.string_representation = formula
+#     self.drivers = drivers
+#     self.custom_drivers = custom_drivers
+#     self.driver_labels = labels
 
-        # compile string representation into code expression
-        self.formula_code = compile(
-            ")\n".join(self.string_representation.split(")")), "<string>", "eval"
-        )
+#     # compile string representation into code expression
+#     self.formula_code = compile(
+#         ")\n".join(self.string_representation.split(")")), "<string>", "eval"
+#     )
 
-        # calc betas
-        self.find_betas()
+#     # calc betas
+#     self.find_betas()
 
-    # creates a string representation of the formula for a given cell json
-    def create_cell_string_representation(
-        self, cell_data, drivers, labels, custom_drivers
-    ):
+# # creates a string representation of the formula for a given cell json
+# def create_cell_string_representation(
+#     self, cell_data, drivers, labels, custom_drivers
+# ):
 
-        # get the formula and no_name of the cell from its json
-        if cell_data["Formula"]:
-            formula = cell_data["Formula"].replace("=", "")
-            formula = formula[0].replace("+", "") + formula[1:]
+#     # get the formula and no_name of the cell from its json
+#     if cell_data["Formula"]:
+#         formula = cell_data["Formula"].replace("=", "")
+#         formula = formula[0].replace("+", "") + formula[1:]
 
-        cell_mo_name = cell_data["RelationalCellAddress"]
-        cell_mo_name = cell_mo_name[1 : cell_mo_name.find("|")]
+#     cell_mo_name = cell_data["RelationalCellAddress"]
+#     cell_mo_name = cell_mo_name[1 : cell_mo_name.find("|")]
 
-        # Base case: if the cell is a driver, custom driver, or if it is historical,
-        # then return that cells value or variable
-        if (
-            cell_data["PrecedentCellsCount"] == 0
-            or cell_data["IsHistorical"]
-            or cell_mo_name in custom_drivers
-        ):
+#     # Base case: if the cell is a driver, custom driver, or if it is historical,
+#     # then return that cells value or variable
+#     if (
+#         cell_data["PrecedentCellsCount"] == 0
+#         or cell_data["IsHistorical"]
+#         or cell_mo_name in custom_drivers
+#     ):
 
-            # for drivers, add them to the right dictionary and return the mo name
-            if cell_data["IsDriver"]:
-                drivers[cell_mo_name] = float(cell_data["Value"])
+#         # for drivers, add them to the right dictionary and return the mo name
+#         if cell_data["IsDriver"]:
+#             drivers[cell_mo_name] = float(cell_data["Value"])
 
-                labels[cell_mo_name] = cell_data["TimeSeriesDescription"]
-                to_return = cell_mo_name
+#             labels[cell_mo_name] = cell_data["TimeSeriesDescription"]
+#             to_return = cell_mo_name
 
-            # do the same for custom drivers but with the custom drivers dict
-            elif cell_mo_name in custom_drivers:
-                custom_drivers[cell_mo_name] = float(cell_data["Value"])
+#         # do the same for custom drivers but with the custom drivers dict
+#         elif cell_mo_name in custom_drivers:
+#             custom_drivers[cell_mo_name] = float(cell_data["Value"])
 
-                labels[cell_mo_name] = float(cell_data["Value"])
-                to_return = cell_mo_name
+#             labels[cell_mo_name] = float(cell_data["Value"])
+#             to_return = cell_mo_name
 
-            # Otherwise return the value of the cell
-            else:
-                v = cell_data["Value"]
-                if v is None:
-                    v = "0.0"
-                to_return = v
+#         # Otherwise return the value of the cell
+#         else:
+#             v = cell_data["Value"]
+#             if v is None:
+#                 v = "0.0"
+#             to_return = v
 
-            # making sure date values are adding with quotations around them
-            if cell_data["Formula"] and "EOMONTH" in cell_data["Formula"]:
-                return f'("{to_return}")'
-            return f"({to_return})"
+#         # making sure date values are adding with quotations around them
+#         if cell_data["Formula"] and "EOMONTH" in cell_data["Formula"]:
+#             return f'("{to_return}")'
+#         return f"({to_return})"
 
-        # Recursive case: loop through the precedent cells of this cell, and replace
-        # the formula with the string formulas of those cells
-        for prec_cell_data in cell_data["PrecedentCells"]:
-            # set the value to replace (the precedent cell's address)
-            val_to_replace = prec_cell_data["SimpleAddress"]
-            prec_cell_mo_name = prec_cell_data["RelationalCellAddress"]
-            prec_cell_mo_name = prec_cell_mo_name[1 : prec_cell_mo_name.find("|")]
+#     # Recursive case: loop through the precedent cells of this cell, and replace
+#     # the formula with the string formulas of those cells
+#     for prec_cell_data in cell_data["PrecedentCells"]:
+#         # set the value to replace (the precedent cell's address)
+#         val_to_replace = prec_cell_data["SimpleAddress"]
+#         prec_cell_mo_name = prec_cell_data["RelationalCellAddress"]
+#         prec_cell_mo_name = prec_cell_mo_name[1 : prec_cell_mo_name.find("|")]
 
-            # set the value to insert into the formula (the precedent cell's formula)
-            if prec_cell_mo_name not in self.cell_formulas:
-                val_to_insert = self.create_cell_string_representation(
-                    prec_cell_data, drivers, labels, custom_drivers
-                )
-                self.cell_formulas[prec_cell_mo_name] = val_to_insert
+#         # set the value to insert into the formula (the precedent cell's formula)
+#         if prec_cell_mo_name not in self.cell_formulas:
+#             val_to_insert = self.create_cell_string_representation(
+#                 prec_cell_data, drivers, labels, custom_drivers
+#             )
+#             self.cell_formulas[prec_cell_mo_name] = val_to_insert
 
-            else:
-                val_to_insert = self.cell_formulas[prec_cell_mo_name]
+#         else:
+#             val_to_insert = self.cell_formulas[prec_cell_mo_name]
 
-            # change ^ (exp in excel) to ** (exp in python)
-            formula = formula.replace("^", "**")
+#         # change ^ (exp in excel) to ** (exp in python)
+#         formula = formula.replace("^", "**")
 
-            # replace the cell address with its formula
-            if val_to_replace in formula:
-                # formula = formula.replace(val_to_replace, f"({val_to_insert})")
-                # use re.sub with \bstr\b to only replace exactly that formula
-                formula = re.sub(
-                    r"\b" + val_to_replace + r"\b", f"({val_to_insert})", formula
-                )
+#         # replace the cell address with its formula
+#         if val_to_replace in formula:
+#             # formula = formula.replace(val_to_replace, f"({val_to_insert})")
+#             # use re.sub with \bstr\b to only replace exactly that formula
+#             formula = re.sub(
+#                 r"\b" + val_to_replace + r"\b", f"({val_to_insert})", formula
+#             )
 
-        return formula
+#     return formula
 
 
 # a class of multiple models
